==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapOTPPolicyEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapOTPPolicyEntityDelegate implements org.keycloak.models.map.realm.entity.MapOTPPolicyEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapOTPPolicyEntity> delegateProvider;
    public MapOTPPolicyEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapOTPPolicyEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public Integer getOtpPolicyInitialCounter() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_INITIAL_COUNTER).getOtpPolicyInitialCounter();
    }
    @Override public void setOtpPolicyInitialCounter(Integer otpPolicyInitialCounter) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_INITIAL_COUNTER, otpPolicyInitialCounter).setOtpPolicyInitialCounter(otpPolicyInitialCounter);
    }
    @Override public Integer getOtpPolicyDigits() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_DIGITS).getOtpPolicyDigits();
    }
    @Override public void setOtpPolicyDigits(Integer otpPolicyDigits) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_DIGITS, otpPolicyDigits).setOtpPolicyDigits(otpPolicyDigits);
    }
    @Override public Integer getOtpPolicyLookAheadWindow() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_LOOK_AHEAD_WINDOW).getOtpPolicyLookAheadWindow();
    }
    @Override public void setOtpPolicyLookAheadWindow(Integer otpPolicyLookAheadWindow) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_LOOK_AHEAD_WINDOW, otpPolicyLookAheadWindow).setOtpPolicyLookAheadWindow(otpPolicyLookAheadWindow);
    }
    @Override public Integer getOtpPolicyPeriod() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_PERIOD).getOtpPolicyPeriod();
    }
    @Override public void setOtpPolicyPeriod(Integer otpPolicyPeriod) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_PERIOD, otpPolicyPeriod).setOtpPolicyPeriod(otpPolicyPeriod);
    }
    @Override public String getOtpPolicyType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_TYPE).getOtpPolicyType();
    }
    @Override public void setOtpPolicyType(String otpPolicyType) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_TYPE, otpPolicyType).setOtpPolicyType(otpPolicyType);
    }
    @Override public String getOtpPolicyAlgorithm() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_ALGORITHM).getOtpPolicyAlgorithm();
    }
    @Override public void setOtpPolicyAlgorithm(String otpPolicyAlgorithm) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_ALGORITHM, otpPolicyAlgorithm).setOtpPolicyAlgorithm(otpPolicyAlgorithm);
    }
}

==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/realm/entity/MapOTPPolicyEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapOTPPolicyEntityDelegate implements org.keycloak.models.map.realm.entity.MapOTPPolicyEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapOTPPolicyEntity> delegateProvider;
    public MapOTPPolicyEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapOTPPolicyEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public Integer getOtpPolicyInitialCounter() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_INITIAL_COUNTER).getOtpPolicyInitialCounter();
    }
    @Override public void setOtpPolicyInitialCounter(Integer otpPolicyInitialCounter) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_INITIAL_COUNTER, otpPolicyInitialCounter).setOtpPolicyInitialCounter(otpPolicyInitialCounter);
    }
    @Override public Integer getOtpPolicyDigits() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_DIGITS).getOtpPolicyDigits();
    }
    @Override public void setOtpPolicyDigits(Integer otpPolicyDigits) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_DIGITS, otpPolicyDigits).setOtpPolicyDigits(otpPolicyDigits);
    }
    @Override public Integer getOtpPolicyLookAheadWindow() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_LOOK_AHEAD_WINDOW).getOtpPolicyLookAheadWindow();
    }
    @Override public void setOtpPolicyLookAheadWindow(Integer otpPolicyLookAheadWindow) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_LOOK_AHEAD_WINDOW, otpPolicyLookAheadWindow).setOtpPolicyLookAheadWindow(otpPolicyLookAheadWindow);
    }
    @Override public Integer getOtpPolicyPeriod() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_PERIOD).getOtpPolicyPeriod();
    }
    @Override public void setOtpPolicyPeriod(Integer otpPolicyPeriod) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_PERIOD, otpPolicyPeriod).setOtpPolicyPeriod(otpPolicyPeriod);
    }
    @Override public String getOtpPolicyType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_TYPE).getOtpPolicyType();
    }
    @Override public void setOtpPolicyType(String otpPolicyType) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_TYPE, otpPolicyType).setOtpPolicyType(otpPolicyType);
    }
    @Override public String getOtpPolicyAlgorithm() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_ALGORITHM).getOtpPolicyAlgorithm();
    }
    @Override public void setOtpPolicyAlgorithm(String otpPolicyAlgorithm) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_ALGORITHM, otpPolicyAlgorithm).setOtpPolicyAlgorithm(otpPolicyAlgorithm);
    }
    @Override public Boolean isOtpPolicyCodeReusable() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_CODE_REUSABLE).isOtpPolicyCodeReusable();
    }
    @Override public void setOtpPolicyCodeReusable(Boolean isOtpPolicyCodeReusable) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapOTPPolicyEntityFields.OTP_POLICY_CODE_REUSABLE, isOtpPolicyCodeReusable).setOtpPolicyCodeReusable(isOtpPolicyCodeReusable);
    }
}
